@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import sys
 from typing import Any
 
@@ -6,7 +8,7 @@ from django.conf import settings
 if sys.version_info >= (3, 8):
     from typing import Literal
 
-    ModeType = Literal["once", "none", "all"]
+    ModeType = Literal["all", "none", "once", "overwrite"]
 else:
     ModeType = str
 
